"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handle = void 0;
const init_1 = require("../init");
const api_1 = require("./api");
const debug_1 = require("../debug");
let initPromise;
let callInit = true;
const isApi = (event) => {
    return event.pathParameters !== undefined ? api_1.apiHandler : false;
};
const throwUnhandledEvent = () => {
    const error = new Error('Unhandled event');
    error.name = 'UnhandledEvent';
    throw error;
};
const handle = (next, shouldThrowOnUnhandled = true) => {
    debug_1.log.debug('[HANDLE] Handling event with function', next.name);
    if (callInit) {
        debug_1.log.debug('[HANDLE] Calling initializers');
        callInit = false;
        initPromise = (0, init_1.runInitializers)();
    }
    return async (event, context, callback) => {
        await initPromise;
        debug_1.log.debug('[HANDLE] Initializers ran successfully');
        debug_1.log.debug('[HANDLE] Is API Gateway handler', isApi(event));
        for (const check of [isApi]) {
            const result = check(event);
            if (result) {
                return result(next)(event, context, callback);
            }
        }
        if (shouldThrowOnUnhandled) {
            debug_1.log.debug('[HANDLE] Unhandled event !');
            throwUnhandledEvent();
        }
        debug_1.log.debug('[HANDLE] Using default handler');
        return next(event, context);
    };
};
exports.handle = handle;
//# sourceMappingURL=index.js.map