import { ApiAfterMiddleware, ApiBeforeMiddleware, ApiErrorHandler } from './api';
import { Context } from 'aws-lambda';
export type DefaultBeforeMiddleware = (event: any, context: Context) => Promise<void>;
export type BeforeMiddleware = ApiBeforeMiddleware | DefaultAfterMiddleware;
export type DefaultAfterMiddleware = (event: any, result: any) => Promise<void>;
export type AfterMiddleware = ApiAfterMiddleware | DefaultAfterMiddleware;
export type DefaultErrorHandler = (event: any, error: any, result: any) => Promise<void>;
export type ErrorHandler = ApiErrorHandler | DefaultErrorHandler;
export type HandlingType = 'ApiGateway';
export type MiddlewareListItem<Before, After, ErrHandler> = {
    before: Before[];
    after: After[];
    errors: ErrHandler[];
};
export type MiddlewareList = {
    __ALWAYS__: MiddlewareListItem<DefaultBeforeMiddleware, DefaultAfterMiddleware, DefaultErrorHandler>;
    ApiGateway: MiddlewareListItem<ApiBeforeMiddleware, ApiAfterMiddleware, ApiErrorHandler>;
};
export declare const callBeforeMiddleware: <T extends (event: any, context: Context) => any>(type: HandlingType, args: Parameters<T>) => Promise<void>;
export declare const callAfterMiddleware: <T extends (event: any, result: any) => any>(type: HandlingType, args: Parameters<T>) => Promise<void>;
export declare const callErrorHandlers: <T extends (event: any, error: any, result: any) => any>(type: HandlingType, args: Parameters<T>) => Promise<void>;
export declare function before(type: 'ApiGateway', middleware: ApiBeforeMiddleware[]): void;
export declare function before(middleware: DefaultBeforeMiddleware[]): void;
export declare function after(type: 'ApiGateway', middleware: ApiAfterMiddleware[]): void;
export declare function after(middleware: DefaultAfterMiddleware[]): void;
export declare function handleError(type: 'ApiGateway', middleware: ApiErrorHandler[]): void;
export declare function handleError(middleware: DefaultErrorHandler[]): void;
