"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.callErrorHandlers = exports.callAfterMiddleware = exports.callBeforeMiddleware = void 0;
exports.before = before;
exports.after = after;
exports.handleError = handleError;
const debug_1 = require("../debug");
const middlewareList = {
    __ALWAYS__: { before: [], after: [], errors: [] },
    ApiGateway: { before: [], after: [], errors: [] },
};
const isSendingType = (typeOrMiddleware) => typeof typeOrMiddleware === 'string';
const callBeforeMiddleware = async (type, args) => {
    debug_1.log.debug('[MIDDLEWARE][BEFORE] Running generic middleware', middlewareList.__ALWAYS__.before.map((f) => f.name));
    for (const middleware of middlewareList.__ALWAYS__.before) {
        await middleware.apply({}, args);
    }
    debug_1.log.debug('[MIDDLEWARE][BEFORE] Running API gateway middleware', middlewareList.ApiGateway.before.map((f) => f.name));
    for (const middleware of middlewareList.ApiGateway.before) {
        await middleware.apply({}, args);
    }
};
exports.callBeforeMiddleware = callBeforeMiddleware;
const callAfterMiddleware = async (type, args) => {
    debug_1.log.debug('[MIDDLEWARE][AFTER] Running generic middleware', middlewareList.__ALWAYS__.after.map((f) => f.name));
    for (const middleware of middlewareList.ApiGateway.after) {
        await middleware.apply({}, args);
    }
    debug_1.log.debug('[MIDDLEWARE][AFTER] Running API gateway middleware', middlewareList.ApiGateway.after.map((f) => f.name));
    for (const middleware of middlewareList.__ALWAYS__.after) {
        await middleware.apply({}, args);
    }
};
exports.callAfterMiddleware = callAfterMiddleware;
const callErrorHandlers = async (type, args) => {
    debug_1.log.debug('[MIDDLEWARE][ERROR] Running generic middleware', middlewareList.__ALWAYS__.errors.map((f) => f.name));
    for (const middleware of middlewareList.ApiGateway.errors) {
        await middleware.apply({}, args);
    }
    debug_1.log.debug('[MIDDLEWARE][ERROR] Running API gateway middleware', middlewareList.ApiGateway.errors.map((f) => f.name));
    for (const middleware of middlewareList.__ALWAYS__.errors) {
        await middleware.apply({}, args);
    }
};
exports.callErrorHandlers = callErrorHandlers;
function before(typeOrMiddleware, middleware = []) {
    debug_1.log.debug('[MIDDLEWARE][BEFORE] Registering middleware', {
        type: Array.isArray(typeOrMiddleware) ? '__ALWAYS__' : typeOrMiddleware,
        middleware: Array.isArray(typeOrMiddleware) ? typeOrMiddleware.map((f) => f.name) : middleware.map((f) => f.name),
    });
    if (!isSendingType(typeOrMiddleware)) {
        middlewareList['__ALWAYS__'].before = typeOrMiddleware;
    }
    else {
        middlewareList[typeOrMiddleware].before = middleware;
    }
}
function after(typeOrMiddleware, middleware = []) {
    debug_1.log.debug('[MIDDLEWARE][AFTER] Registering middleware', {
        type: Array.isArray(typeOrMiddleware) ? '__ALWAYS__' : typeOrMiddleware,
        middleware: Array.isArray(typeOrMiddleware) ? typeOrMiddleware.map((f) => f.name) : middleware.map((f) => f.name),
    });
    if (!isSendingType(typeOrMiddleware)) {
        middlewareList['__ALWAYS__'].after = typeOrMiddleware;
    }
    else {
        middlewareList[typeOrMiddleware].after = middleware;
    }
}
function handleError(typeOrMiddleware, middleware = []) {
    debug_1.log.debug('[MIDDLEWARE][ERROR] Registering middleware', {
        type: Array.isArray(typeOrMiddleware) ? '__ALWAYS__' : typeOrMiddleware,
        middleware: Array.isArray(typeOrMiddleware) ? typeOrMiddleware.map((f) => f.name) : middleware.map((f) => f.name),
    });
    if (!isSendingType(typeOrMiddleware)) {
        middlewareList['__ALWAYS__'].errors = typeOrMiddleware;
    }
    else {
        middlewareList[typeOrMiddleware].errors = middleware;
    }
}
//# sourceMappingURL=middleware.js.map