"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.injectSecrets = void 0;
const client_secrets_manager_1 = require("@aws-sdk/client-secrets-manager");
const client_ssm_1 = require("@aws-sdk/client-ssm");
const getSecret = async (name, version) => {
    const secretManager = new client_secrets_manager_1.SecretsManagerClient({
        region: process.env.AWS_REGION,
    });
    const getValue = new client_secrets_manager_1.GetSecretValueCommand({
        SecretId: name,
        VersionId: version,
    });
    return (await secretManager.send(getValue)).SecretString;
};
const getParameterValue = async (name) => {
    const ssm = new client_ssm_1.SSMClient({
        region: process.env.AWS_REGION,
    });
    const getValue = new client_ssm_1.GetParameterCommand({
        Name: name,
    });
    return (await ssm.send(getValue)).Parameter?.Value;
};
const injectSecrets = async () => {
    const resolveSpecialEnvVars$ = [];
    for (const key of Object.keys(process.env)) {
        const isSsmParameter = process.env[key]?.match(/^\$\{ssm:(.+)}$/);
        const isSecret = process.env[key]?.match(/^\$\{secret:(.+)}$/);
        if (isSecret) {
            let version;
            let name = isSecret[1];
            const hasVersion = isSecret[1].match(/^(.+):(.+)$/);
            if (hasVersion) {
                name = hasVersion[1];
                version = hasVersion[2];
            }
            resolveSpecialEnvVars$.push(getSecret(name, version)
                .then((value) => {
                process.env[key] = value;
            })
                .catch((e) => {
                console.warn('Error injecting secret', isSecret[1], e);
                delete process.env[key];
            }));
        }
        else if (isSsmParameter) {
            resolveSpecialEnvVars$.push(getParameterValue(isSsmParameter[1])
                .then((value) => {
                process.env[key] = value;
            })
                .catch((e) => {
                console.warn('Error injecting secret', isSsmParameter[1], e);
                delete process.env[key];
            }));
        }
    }
    await Promise.all(resolveSpecialEnvVars$);
};
exports.injectSecrets = injectSecrets;
//# sourceMappingURL=inject-secrets-middleware.js.map